@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -23,17 +24,17 @@
 namespace polymake { namespace polytope {
 
 template <typename Decoration, typename SeqType>
-Graph<> vertex_graph(perl::Object HD_obj)
+Graph<> vertex_graph(BigObject HD_obj)
 {
    const graph::Lattice<Decoration, SeqType> HD(HD_obj);
-   const int hd_rank = HD.rank();
+   const Int hd_rank = HD.rank();
    if (hd_rank<=0) return Graph<>(0);
    Graph<> G(HD.nodes_of_rank(1).size());
 
    // vertex sets stored by the polytope edge faces (dim==1)
    // are exactly the vertex pairs we need for the graph
    if (hd_rank > 1) {
-      for (auto f_it = entire(attach_member_accessor(select(HD.decoration(), HD.nodes_of_rank(2)), ptr2type<graph::lattice::BasicDecoration, Set<int>, &graph::lattice::BasicDecoration::face>())); !f_it.at_end(); ++f_it) {
+      for (auto f_it = entire(attach_member_accessor(select(HD.decoration(), HD.nodes_of_rank(2)), ptr2type<graph::lattice::BasicDecoration, Set<Int>, &graph::lattice::BasicDecoration::face>())); !f_it.at_end(); ++f_it) {
          G.edge(f_it->front(), f_it->back());
       }
    }
@@ -41,17 +42,17 @@ Graph<> vertex_graph(perl::Object HD_obj)
 }
 
 template <typename Decoration, typename SeqType>
-Graph<> facet_graph(perl::Object HD_obj)
+Graph<> facet_graph(BigObject HD_obj)
 {
    const graph::Lattice<Decoration, SeqType> HD(HD_obj);
-   const int hd_rank = HD.rank();
+   const Int hd_rank = HD.rank();
    if (hd_rank<=0) return Graph<>(0);
    const auto& facet_nodes = HD.nodes_of_rank(hd_rank-1);
    Graph<> G(facet_nodes.size());
 
    // the node numbers of the polytope facets (which are neighbors of the ridge faces, dim==-2)
    // relate to the whole Hasse diagram graph!
-   int node_shift = facet_nodes.front();
+   Int node_shift = facet_nodes.front();
    if (hd_rank > 1) {
       for (auto f_it = entire(select(rows(adjacency_matrix(HD.graph())), HD.nodes_of_rank(hd_rank-2)));
             !f_it.at_end(); ++f_it) {
